@@ -655,7 +655,18 @@ isat.default <- function(y, mc=TRUE, ar=NULL, ewma=NULL, mxreg=NULL,
     if( is.null(plot) ){ plot <- FALSE }
   }
   if(plot){ plot.isat(getsis, coef.path=TRUE) }
-
+  
+  ## Outlier Proportion and Distortion Test 
+  # Proportion Test was previously executed in the print.isat function
+  if(!is.null(getsis$call$iis) & isTRUE(eval(getsis$call$iis))){
+    if(!any(eval(getsis$call$sis), eval(getsis$call$tis), 
+            ifelse(is.logical(eval(getsis$call$uis)) & isTRUE(eval(getsis$call$uis)), TRUE, FALSE))){
+      
+      getsis$outlier.proportion.test <- outliertest(getsis)
+      getsis$outlier.distortion.test <- distorttest(getsis)
+      }
+    }
+  
   return(getsis)
 
 } #close isat function
@@ -710,6 +721,10 @@ gets.isat <- function(x, t.pval=0.05, wald.pval=t.pval, vcov.type = NULL,
   mxreg <- x$aux$mX
   colnames(mxreg) <- x$aux$mXnames
 
+  # Save original arx mc warning setting and disable it here
+  tmpmc <- getOption("mc.warning")
+  options(mc.warning = FALSE)
+  
   object <- do.call("arx", 
                     list(y = y, mxreg = mxreg,
                          ewma = NULL, mc = FALSE, ar = NULL, log.ewma = NULL, # would be in mxreg already
@@ -753,6 +768,10 @@ gets.isat <- function(x, t.pval=0.05, wald.pval=t.pval, vcov.type = NULL,
     plot,
     alarm
   )
+  
+  # Set the old arx mc warning again
+  options(mc.warning = tmpmc)
+  
   return(out)
   
 } #close gets.isat() function
@@ -762,7 +781,9 @@ logLik.isat <- function(object, ...)
 {
   result <- object$logl
   if(is.null(result)){
-    result <- numeric(0)
+    result <- NA # numeric(0) will throw error, cannot replace cell with numeric vector of length 0
+    #OLD:
+    #result <- numeric(0)
     warning("'object$logl' is NULL")
   }else{
     attr(result, "df") <- length(object$coefficients)
@@ -1205,27 +1226,34 @@ print.isat <- function(x, signif.stars=TRUE, ...)
       cat("Diagnostics and fit:\n")
       cat("\n")
       printCoefmat(x$diagnostics, tst.ind=2,signif.stars=signif.stars, has.Pvalue = TRUE)
-      if(!is.null(x$call$iis)){
-        #OLD:
-        #      if (x$call$iis==TRUE){
-        if (x$call$iis==TRUE){        outltest <- outliertest(x)
-        mOutl <- matrix(NA, 2, 2)
-        colnames(mOutl) <- c("Stat.", "p-value")
-        rownames(mOutl) <- c("Jiao-Pretis Prop.", "Jiao-Pretis Count")
-        mOutl[1,] <- c(outltest$prop$statistic, outltest$prop$p.value)
-        mOutl[2,] <- c(outltest$count$statistic, outltest$count$p.value)
+      
+      
+      if(!is.null(x$outlier.distortion.test)){
+        #cat("\nJiao-Pretis-Schwarz Outlier Distortion Test")
+        mOutl_d <- matrix(NA, 1, 3)
+        colnames(mOutl_d) <- c("Chi-sq","df", "p-value")
+        rownames(mOutl_d) <- c("Jiao-Pretis-Schwarz Outlier Distortion")
+        mOutl_d[1,] <- c(x$outlier.distortion.test$statistic,x$outlier.distortion.test$df,x$outlier.distortion.test$p.value)
         cat("\n")
-#OLD:
-#        printCoefmat(mOutl, digits=6, signif.stars = FALSE) 
-        printCoefmat(mOutl, digits=6, signif.stars = TRUE) 
-        #cat("\n")
-        }
+        printCoefmat(mOutl_d, digits=6, signif.stars = TRUE,P.values = TRUE, has.Pvalue = TRUE, signif.legend = FALSE)
       }
+      
+      if(!is.null(x$outlier.proportion.test)){
+        #cat("\nJiao-Pretis Outlier Proportion Test")
+        mOutl_p <- matrix(NA, 2, 2)
+        colnames(mOutl_p) <- c("Stat.", "p-value")
+        rownames(mOutl_p) <- c("Jiao-Pretis Outlier Proportion", "Jiao-Pretis Outlier Count")
+        mOutl_p[1,] <- c(x$outlier.proportion.test$prop$statistic, x$outlier.proportion.test$prop$p.value)
+        mOutl_p[2,] <- c(x$outlier.proportion.test$count$statistic, x$outlier.proportion.test$count$p.value)
+        cat("\n")
+        printCoefmat(mOutl_p, digits=6, signif.stars = TRUE,P.values = TRUE, has.Pvalue = TRUE, signif.legend = FALSE) 
+      }
+      
       printCoefmat(mGOF, digits=6, signif.stars=signif.stars)
       
     }
     
-  }
+}
 
 #OLD:
 ##==================================================
@@ -1381,7 +1409,9 @@ residuals.isat <- function(object, std=FALSE, ...)
 sigma.isat <- function(object, ...)
 {
   if(is.null(object$residuals)){
-    result <- NULL
+    result <- NA # J-bat: should not set NULL otherwise cannot replace cell in matrix
+    #OLD:
+    #result <- NULL
   }else{
     RSS <- sum(object$residuals^2)
     result <- sqrt(RSS/(object$n - object$k))
@@ -1682,11 +1712,16 @@ isatvar <- function(x, lr=FALSE, conscorr=FALSE, effcorr=FALSE, mcor = 1,  mxful
       if (conscorr==TRUE){
         x$vcov.mean <- x$vcov.mean*as.numeric(isvarcor(x$aux$t.pval,1)[2]^2)
       }
-
-      if (effcorr==TRUE){
-
-        if (!is.null(x$keep)) {
-          x$vcov.mean[x$keep, x$keep] <- x$vcov.mean[x$keep, x$keep] * as.numeric(isvareffcor(x$aux$t.pval, 1, mcor)[2]^2)
+      
+      if (effcorr == TRUE){
+        rel_names <- x$aux$mXnames[!(x$aux$mXnames %in% x$ISnames)]
+        if (!is.null(rel_names)) {
+          # OLD:
+          #if (!is.null(x$keep)) {
+          # x$vcov.mean[x$keep, x$keep] <- x$vcov.mean[x$keep, x$keep] * as.numeric(isvareffcor(x$aux$t.pval, 1, mcor)[2]^2)
+          x$vcov.mean[rel_names, rel_names] <- x$vcov.mean[rel_names, 
+                                                           rel_names] * as.numeric(isvareffcor(x$aux$t.pval,
+                                                                                               1, mcor)[2]^2)
         }
       }
 
@@ -2680,11 +2715,13 @@ isatdates <- function(x){
 
 isatvarcorrect <- function(x,   mcor = 1){
   
-  if (class(x)=="isat"){
-    if (x$call$iis==TRUE) 
+  classx <- class(x)
+  if (classx=="isat"){
+    if (!is.null(x$call$iis) & x$call$iis==TRUE) 
     {
       x$vcov.mean <- x$vcov.mean * as.numeric(isvarcor(x$aux$t.pval, 1)[2]^2)
-      x$vcov.mean[x$keep, x$keep] <- x$vcov.mean[x$keep, x$keep] * as.numeric(isvareffcor(x$aux$t.pval, 1, mcor)[2]^2)
+      rel_names <- x$aux$mXnames[!(x$aux$mXnames %in% x$ISnames)]
+      x$vcov.mean[rel_names, rel_names] <- x$vcov.mean[rel_names, rel_names] * as.numeric(isvareffcor(x$aux$t.pval, 1, mcor)[2]^2)
       
       x$mean.results$std.error <- sqrt(diag(x$vcov.mean))
       x$mean.results$`t-stat` <- x$mean.results$coef/x$mean.results$std.error
@@ -2745,7 +2782,7 @@ vargaugeiis <- function(t.pval, T, infty=FALSE, m=1){
 }  
 
 ################
-#### outliertest
+#### outlier Proportion Test
 ################
 
 #### Outlier proportion and count tests from Jiao and Pretis (2019)
@@ -2757,10 +2794,10 @@ outliertest <- function(x=NULL, noutl=NULL, t.pval=NULL, T=NULL,  m=1, infty=FAL
     # t.pval=x$obs.gauge$t.pval[i]
     # T=x$n
     # 
-    
     if (!is.null(x)){
       
-      if (class(x)=="isat"){
+      classx <- class(x)
+      if (classx=="isat"){
         
         # if (any(x$call$sis, x$call$tis)==TRUE ){
         #   stop("Test only valid for iis")
@@ -2870,7 +2907,7 @@ isatloop <- function(num=c(seq(from=20, to=1, by=-1)), t.pval.spec = FALSE, prin
     {
       print(paste("k:", k, "/", K, ", p:", pval, sep=""))
     }
-    x <- isat(y=y, iis=iis, sis=sis, t.pval=pval, ar=ar, ...) 
+    x <- do.call("isat", args = list(y = y, iis = iis, sis = sis, t.pval = pval, ar = ar, ...))
     
     #mxreg=mxreg, mc=mc, 
     if (!is.null(x$ISnames)) {
